/*
 * 
 */
package org.gcube.datacatalogue.ckanutillibrary.gcat;

import java.net.MalformedURLException;

import org.gcube.gcat.client.Group;
import org.gcube.gcat.client.Item;
import org.gcube.gcat.client.Resource;
import org.json.simple.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

// TODO: Auto-generated Javadoc
/**
 * The Class GCatCaller.
 *
 * @author Francesco Mangiacrapa at ISTI-CNR Pisa (Italy)
 * May 29, 2020
 */
public class GCatCaller {
	
	private String catalogueURL;
	
	private static final Logger LOG = LoggerFactory.getLogger(GCatCaller.class);
	
	/**
	 * Instantiates a new g cat caller.
	 *
	 * @param catalogueURL the catalogue URL
	 */
	public GCatCaller(String catalogueURL) {
		this.catalogueURL = catalogueURL;
	}
	
	
	/**
	 * Gets the dataset for name.
	 *
	 * @param datasetIdOrName the dataset id or name
	 * @return the jsonValue
	 * @throws MalformedURLException the malformed URL exception
	 */
	public String getDatasetForName(String datasetIdOrName) throws MalformedURLException {
		LOG.debug("Get dataset for name "+datasetIdOrName+ "called");
		return new Item().read(datasetIdOrName);
	}
	
	
	/**
	 * Creates the dataset.
	 *
	 * @param jsonDataset the json dataset
	 * @param socialPost if true sends the social post
	 * @return the jsonValue
	 * @throws MalformedURLException the malformed URL exception
	 */
	public String createDataset(String jsonDataset, boolean socialPost) throws MalformedURLException {
		LOG.debug("Create dataset called");
		return new Item().create(jsonDataset,socialPost);
	}
	
	
	/**
	 * Adds the resource to dataset.
	 *
	 * @param datasetId the dataset id
	 * @param jsonValueResource the json value resource
	 * @return the string
	 * @throws MalformedURLException the malformed URL exception
	 */
	public String addResourceToDataset(String datasetId, String jsonValueResource) throws MalformedURLException {
		LOG.debug("Create resource called");
		return new Resource().create(datasetId, jsonValueResource);
	}
	
	
	/**
	 * Delete resource.
	 *
	 * @param datasetId the dataset id
	 * @param resourceId the resource id
	 * @throws MalformedURLException the malformed URL exception
	 */
	public void deleteResource(String datasetId, String resourceId) throws MalformedURLException {
		LOG.debug("Delete resource called");
		new Resource().delete(datasetId, resourceId);
	}
	
	
	/**
	 * Gets the catalogue URL.
	 *
	 * @return the catalogue URL
	 */
	public String getCatalogueURL() {
		return catalogueURL;
	}

	
	/**
	 * Creates the group.
	 *
	 * @param jsonGroup the json group
	 * @return the string
	 * @throws MalformedURLException the malformed URL exception
	 */
	public String createGroup(String jsonGroup) throws MalformedURLException {
		LOG.debug("Create group called");
		return new Group().create(jsonGroup);
	}
	
	
	/**
	 * 
	 * TODO MUST BE COMPLETED
	 * 
	 * Patch dataset.
	 *
	 * @param datasetId the dataset id
	 * @param jsonObj the json obj
	 * @throws Exception the exception
	 */
	public void patchDataset(String datasetId, JSONObject jsonObj) throws Exception {

		//String searchableAsString = searchable ? "True" : "False";

		JSONObject obj = new JSONObject();
		jsonObj.put("id", datasetId); //just to be sure
		//obj.put("searchable", searchableAsString);
		
		throw new Exception("Method patchDataset is missing by gCat CL");
	}

}
